Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1039)

Unified Diff: chrome/browser/login_prompt.cc

Issue 5384002: net: Remove typedef net::URLRequest URLRequest; (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: review Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/login_prompt.cc
diff --git a/chrome/browser/login_prompt.cc b/chrome/browser/login_prompt.cc
index 69e0f200c3438b178b0f94344333d9939a2e6778..47346c040d76712fa68b823504c4b7e2d609b8f8 100644
--- a/chrome/browser/login_prompt.cc
+++ b/chrome/browser/login_prompt.cc
@@ -30,9 +30,10 @@ using webkit_glue::PasswordForm;
class LoginHandlerImpl;
-// Helper to remove the ref from an URLRequest to the LoginHandler.
-// Should only be called from the IO thread, since it accesses an URLRequest.
-void ResetLoginHandlerForRequest(URLRequest* request) {
+// Helper to remove the ref from an net::URLRequest to the LoginHandler.
+// Should only be called from the IO thread, since it accesses an
+// net::URLRequest.
+void ResetLoginHandlerForRequest(net::URLRequest* request) {
ResourceDispatcherHostRequestInfo* info =
ResourceDispatcherHost::InfoForRequest(request);
if (!info)
@@ -69,7 +70,7 @@ std::string GetSignonRealm(const GURL& url,
// LoginHandler
LoginHandler::LoginHandler(net::AuthChallengeInfo* auth_info,
- URLRequest* request)
+ net::URLRequest* request)
: handled_auth_(false),
dialog_(NULL),
auth_info_(auth_info),
@@ -351,7 +352,7 @@ void LoginHandler::CloseContentsDeferred() {
// This task is run on the UI thread and creates a constrained window with
// a LoginView to prompt the user. The response will be sent to LoginHandler,
// which then routes it to the URLRequest on the I/O thread.
class LoginDialogTask : public Task {
public:
LoginDialogTask(const GURL& request_url,
@@ -426,7 +427,7 @@ class LoginDialogTask : public Task {
handler_->SetPasswordForm(dialog_form);
}
// The url from the URLRequest initiating the auth challenge.
GURL request_url_;
// Info about who/where/what is asking for authentication.
@@ -443,7 +444,7 @@ class LoginDialogTask : public Task {
// Public API
LoginHandler* CreateLoginPrompt(net::AuthChallengeInfo* auth_info,
- URLRequest* request) {
+ net::URLRequest* request) {
LoginHandler* handler = LoginHandler::Create(auth_info, request);
BrowserThread::PostTask(
BrowserThread::UI, FROM_HERE, new LoginDialogTask(
@@ -351,7 +352,7 @@ void LoginHandler::CloseContentsDeferred() {
// This task is run on the UI thread and creates a constrained window with
// a LoginView to prompt the user. The response will be sent to LoginHandler,
-// which then routes it to the URLRequest on the I/O thread.
+// which then routes it to the net::URLRequest on the I/O thread.
class LoginDialogTask : public Task {
public:
@@ -426,7 +427,7 @@ class LoginDialogTask : public Task {
handler_->SetPasswordForm(dialog_form);
}
- // The url from the URLRequest initiating the auth challenge.
+ // The url from the net::URLRequest initiating the auth challenge.
GURL request_url_;
// Info about who/where/what is asking for authentication.

Powered by Google App Engine
This is Rietveld 408576698